aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu/GrSamplerState.h
diff options
context:
space:
mode:
authorGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-24 18:28:34 +0000
committerGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-24 18:28:34 +0000
commita469c28c3c16214733a25201a286970f57b3d944 (patch)
tree2493bd735990ff40770ed8cfa601db0a2babe549 /include/gpu/GrSamplerState.h
parent96182216f187fd103392ccaa34f505fe54fcff7e (diff)
CustomStage Renaming Part 1
Search and replace: GrCustomStage->GrEffect GrCustomStageTestFactory->GrEffectTestFactory renamed the cpp/h files from customStage->effect reordered gypi, #includes, forward decls to maintain alphabetical sort. manually fixed up some whitespace and linewraps deleted a commented out #include R=robertphillips@google.com Review URL: https://codereview.appspot.com/6758046 git-svn-id: http://skia.googlecode.com/svn/trunk@6076 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/gpu/GrSamplerState.h')
-rw-r--r--include/gpu/GrSamplerState.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/include/gpu/GrSamplerState.h b/include/gpu/GrSamplerState.h
index bb71e92560..98ca51de45 100644
--- a/include/gpu/GrSamplerState.h
+++ b/include/gpu/GrSamplerState.h
@@ -11,7 +11,7 @@
#ifndef GrSamplerState_DEFINED
#define GrSamplerState_DEFINED
-#include "GrCustomStage.h"
+#include "GrEffect.h"
#include "GrMatrix.h"
#include "GrTypes.h"
@@ -70,7 +70,7 @@ public:
class SavedCoordChange {
private:
GrMatrix fCoordChangeMatrix;
- GR_DEBUGCODE(mutable SkAutoTUnref<GrCustomStage> fCustomStage;)
+ GR_DEBUGCODE(mutable SkAutoTUnref<GrEffect> fCustomStage;)
friend class GrSamplerState;
};
@@ -100,7 +100,7 @@ public:
}
/**
* Gets the texture matrix. This is will be removed soon and be managed by GrCustomStage.
*/
const GrMatrix& getMatrix() const { return fMatrix; }
@@ -117,7 +117,7 @@ public:
GrSafeSetNull(fCustomStage);
}
- GrCustomStage* setCustomStage(GrCustomStage* stage) {
+ GrEffect* setCustomStage(GrEffect* stage) {
GrAssert(0 == fSavedCoordChangeCnt);
GrSafeAssign(fCustomStage, stage);
fMatrix.reset();
@@ -125,7 +125,7 @@ public:
return stage;
}
- GrCustomStage* setCustomStage(GrCustomStage* stage, const GrMatrix& matrix) {
+ GrEffect* setCustomStage(GrEffect* stage, const GrMatrix& matrix) {
GrAssert(0 == fSavedCoordChangeCnt);
GrSafeAssign(fCustomStage, stage);
fMatrix = matrix;
@@ -133,12 +133,12 @@ public:
return stage;
}
- const GrCustomStage* getCustomStage() const { return fCustomStage; }
+ const GrEffect* getCustomStage() const { return fCustomStage; }
private:
GrMatrix fCoordChangeMatrix;
- GrMatrix fMatrix; // TODO: remove this, store in GrCustomStage
- GrCustomStage* fCustomStage;
+ GrMatrix fMatrix; // TODO: remove this, store in GrEffect
+ GrEffect* fCustomStage;
GR_DEBUGCODE(mutable int fSavedCoordChangeCnt;)
};
@@ -100,7 +100,7 @@ public:
}
/**
- * Gets the texture matrix. This is will be removed soon and be managed by GrCustomStage.
+ * Gets the texture matrix. This is will be removed soon and be managed by GrEffect.
*/
const GrMatrix& getMatrix() const { return fMatrix; }